@@ -10,13 +10,13 @@
 # These results are stored as rds files in the BasicData folder
 
 
-# Input: Domain (vector),Proteom_ID (vector),Tax_ID (vector),speciesname (vector),forcedl (logical) 
+# Input: Domain (vector),Proteom_ID (vector),Tax_ID (vector),speciesname (vector),forcedl (logical)
 # Output: char vector result contains path to directory with FASTA-rds-files
 #Proteom_ID,Tax_ID,Species
 #UP000005640 9606    HUMAN
-#UP000000589 10090   MOUSE 
+#UP000000589 10090   MOUSE
 #UP000002494 10116   RAT
-#UP000008227 9823    PIG 
+#UP000008227 9823    PIG
 #Domain: Archaea,Bacteria,Eukaryota,Viruses#
 #forcedl: if old databasic/existing files should be replaced
 
@@ -27,40 +27,40 @@ fasta2rds <- function(species=c("HUMAN", "MOUSE", "RAT", "PIG"),
                       domain=rep("Eukaryota",4), forcedl = FALSE)
 {
   #wd <- paste0("bin/")
-  wd <- c("BasicData/") 
+  wd <- c("BasicData/")
   FASTAEndingGZ <- ".fasta.gz"
   FASTAEnding <- ".fasta"
   #FASTAPath <- "ftp://ftp.uniprot.org/pub/databases/uniprot/current_release/knowledgebase/proteomes/"
   FASTAPath <- "ftp://ftp.uniprot.org/pub/databases/uniprot/current_release/knowledgebase/reference_proteomes/"
-  
-  
+
+
   #erstelle eine aktuelle version der Datenbank
   #ACHTUNG: hier auch ueberpruefen ob Datei schon vorhanden
-  #save Uniprot Readme  
+  #save Uniprot Readme
   #check version/ release of Uniprot Data on uniprot and in BasicData folder
   cat("Check version \n")
   bdown("ftp://ftp.uniprot.org/pub/databases/uniprot/current_release/relnotes.txt",
         paste0(wd, "relnotes.txt"))
   version <- gsub(" ", "", readLines(paste0(wd, "relnotes.txt"), 1))
   cat("\n")
-  
+
   if (!dir.exists(paste0(wd, version)))
   {
-    dir.create(paste0(wd, version))      
+    dir.create(paste0(wd, version))
   }
-  
+
   if (!file.exists(paste0(wd, version, "/relnotes.txt")) | forcedl)
   {
     file.copy(paste0(wd, "relnotes.txt"), paste0(wd, version, "/relnotes.txt"), overwrite = FALSE)
   }
-  
+
   file.remove(paste0(wd, "relnotes.txt"))
   result <- paste0(wd, version)
-  
+
   cat("Starting FASTA file download, extraction and RDS creation...\n")
   uniprot <- data.frame(species, proteomeid, taxid, domain, stringsAsFactors = FALSE)
- 
-  
+
+
   for (i in seq_along(uniprot$species))
   {
     s <- uniprot[i,"species"]
@@ -68,7 +68,7 @@ fasta2rds <- function(species=c("HUMAN", "MOUSE", "RAT", "PIG"),
     tid <- uniprot[i,"taxid"]
     d <- uniprot[i,"domain"]
     ################################################
-    ## Download FASTA files 
+    ## Download FASTA files
     ################################################
     FASTAsource <- paste0(FASTAPath, d, "/", pid, "_", tid, FASTAEndingGZ)
     FASTAdest <- paste0(wd, version,"/", s,"_",pid, "_", tid, FASTAEndingGZ)
@@ -76,16 +76,16 @@ fasta2rds <- function(species=c("HUMAN", "MOUSE", "RAT", "PIG"),
     FASTAsourceAdd <- paste0(FASTAPath, d, "/", pid, "_", tid, "_additional", FASTAEndingGZ)
     FASTAdestAdd <- paste0(wd, version,"/", s,"_",pid, "_", tid, "_additional", FASTAEndingGZ)
     FASTAfileAdd <- paste0(wd, version,"/", s,"_",pid, "_", tid, "_additional", FASTAEnding)
-    
+
     FASTArds <- paste0(wd, version, "/", "FASTA", tolower(s), ".rds")
-    
+
     #print(bla)
-    
+
     cat(paste("Start download check:", s, "\n"))
-    
+
     if(!file.exists(FASTAfile) | forcedl )
     {
-      ret <- bdown(FASTAsource, FASTAdest) 
+      ret <- bdown(FASTAsource, FASTAdest)
       cat("\n")
       cat("Extracting:", s, "\n")
       gunzip(FASTAdest, remove=TRUE, overwrite=TRUE)
@@ -94,45 +94,45 @@ fasta2rds <- function(species=c("HUMAN", "MOUSE", "RAT", "PIG"),
     {
       cat(FASTAfile, " is up to date. \n")
     }
-    
+
     if(!file.exists(FASTAfileAdd) | forcedl )
     {
-      retadd <- bdown(FASTAsourceAdd, FASTAdestAdd)  
+      retadd <- bdown(FASTAsourceAdd, FASTAdestAdd)
       cat("\n")
       cat("Extracting:", s, "\n")
       gunzip(FASTAdestAdd, remove=TRUE, overwrite=TRUE)
-    }  
+    }
     else
     {
       cat(FASTAfileAdd, " is up to date. \n")
     }
-    
+
     if (!file.exists(FASTArds) | forcedl )
     {
       cat("Reading FASTA file for", s, "\n")
-      
+
       ###and save as RDS files ##
       FASTAopen <- read.fasta(FASTAfile, as.string=TRUE, seqtype="AA", )
       FASTAopenAdd <- read.fasta(FASTAfileAdd, as.string=TRUE, seqtype="AA", )
       #zusammenfuegen
       FASTAopenTg <- c(FASTAopen,FASTAopenAdd)
       cat("Saving RDS file for", s, "\n")
-      saveRDS(FASTAopenTg, file=FASTArds)       
+      saveRDS(FASTAopenTg, file=FASTArds)
     }
     else
     {
       cat(FASTArds, " is up to date. \n")
     }
-    
-    
+
+
     ######################################################
-    ## Create and save index, accessions, protein names ##  
+    ## Create and save index, accessions, protein names ##
     ######################################################
     if (!file.exists(paste0(wd,version,"/", s,".ACC.RDS"))| forcedl)
     {
       actProteinAcc <- {}
       actProtein <- {}
-      actFASTAindex <- {} 
+      actFASTAindex <- {}
       actFASTA <- FASTAopenTg
       index <- seq(1:length(actFASTA))
       lenFASTA <- length(actFASTA)
@@ -164,80 +164,80 @@ fasta2rds <- function(species=c("HUMAN", "MOUSE", "RAT", "PIG"),
   cat("Finished process for\n")
   cat(species, "\n")
   cat("______________________________________________\n\n")
-  
+
   return(result)
 }
 
 
-#localfasta2rds allows to use a local fasta file. 
+#localfasta2rds allows to use a local fasta file.
 # Input: character vector pathlf (path to local fasta file)
 #         character vector version
 # Output: char vector result contains path to directory with FASTA-rds-files
-localfasta2rds <- function(pathlf, version, org) 
+localfasta2rds <- function(pathlf, version, org)
 {
   if ( !file.exists(pathlf) )
   {
     cat("localfasta2rds ERROR: There is no file called:\n",pathlf,"\n")
     result <- "ERROR"
     return(result)
-  }  
-  
+  }
+
   pathsplit <- unlist(strsplit(pathlf,"/"))
-  fastaname <- pathsplit[length(pathsplit)]  
-  
+  fastaname <- pathsplit[length(pathsplit)]
+
   if(version=="actual")
   {
     cat("Check version \n")
     bdown("ftp://ftp.uniprot.org/pub/databases/uniprot/current_release/relnotes.txt",
           paste0("BasicData/", "relnotes.txt"))
     actversion <- gsub(" ", "", readLines(paste0("BasicData/", "relnotes.txt"), 1))
-    cat("\n")      
+    cat("\n")
     newdir <- paste0("BasicData/", actversion, "_", fastaname, "_", org)
-    
+
     if (dir.exists(newdir))
     {
       cat("localfasta2rds ERROR: there is already a directory:\n", newdir,"\n")
       result <- "ERROR"
-      return(result)      
+      return(result)
     }
-    
+
     dir.create(newdir)
     file.copy(pathlf, paste0(newdir, "/"))
-    
-    
+
+
   } else if (dir.exists(paste0("BasicData/", version))) {
-    
+
     newdir <- paste0("BasicData/",version,"_",fastaname,"_",org)
     if (dir.exists(newdir))
     {
       cat("localfasta2rds ERROR: there is already a directory:\n", newdir,"\n")
       result <- "ERROR"
-      return(result)      
+      return(result)
     }
-    
+
     dir.create(newdir)
-    file.copy(pathlf, paste0( newdir, "/"))    
-    
-    
+    file.copy(pathlf, paste0( newdir, "/"))
+
+
     #version was not correct
   } else {
     cat("localfasta2rds ERROR: no directory matches to the given version \n")
     result <- "ERROR"
     return(result)
   }
-    
+
   # save fasta in RDS
-  FASTAopen <- read.fasta(pathlf, as.string = TRUE, seqtype = "AA", )  
+  FASTAopen <- read.fasta(pathlf, as.string = TRUE, seqtype = "AA", )
   cat("localfasta2rds: Saving FASTA-RDS file for",fastaname , "\n")
   FASTArds <- paste0(newdir, "/FASTA", tolower(org), ".rds")
-  saveRDS(FASTAopen, file = FASTArds)       
-  
+  saveRDS(FASTAopen, file = FASTArds)
+
   #create index
   if (!file.exists(paste0(newdir, "/", toupper(org),".ACC.RDS")))
   {
     actProteinAcc <- {}
     actProtein <- {}
-    actFASTAindex <- {} 
+    actFASTAindex <- {}
     actFASTA <- FASTAopen
     index <- seq(1:length(actFASTA))
     lenFASTA <- length(actFASTA)
@@ -265,8 +265,8 @@ localfasta2rds <- function(pathlf, version, org)
   {
     cat(paste0(newdir,"/", toupper(org),".ACC.RDS"), " is up to date. \n")
   }
-  
-  
+
+
   result <- newdir
   return(result)
 }
@@ -276,20 +276,20 @@ localfasta2rds <- function(pathlf, version, org)
 #########################################
 bdown <- function(url, file)
 {
-  
+
   h <- basicTextGatherer()
   curlPerform(url=url, customrequest='HEAD', header=0L, nobody=1L, headerfunction=h$update)
-  
-  if(grepl('Content-Length: ', h$value())) 
-  {    
+
+  if(grepl('Content-Length: ', h$value()))
+  {
     #print(paste0("bdown Ergebnis Abfrgae Contenlength", grepl("Content-Length:",h$value())))
     size <- as.numeric(strsplit(strsplit(h$value(),'Content-Length: ')[[1]][2],"\r")[[1]][1])
-  } 
-  else 
-  {
-    size <- 1    
   }
-  
+  else
+  {
+    size <- 1
+  }
+
   #size <-2000
   f <- CFILE(file, mode="wb")
   #print(paste0("bdown size: ", size))
@@ -297,18 +297,18 @@ bdown <- function(url, file)
     barWidth <- (getOption("width")-20)
     bar <- txtProgressBar(0, size, style=3, , width=barWidth)
     a <- curlPerform(url=url, noprogress=0L,
-                     writedata = f@ref, 
+                     writedata = f@ref,
                      progressfunction=function(down,up)
                        setTxtProgressBar(bar, down[2]))
   }else{
     a <- curlPerform(url=url, noprogress=0L,
-                     writedata = f@ref, 
+                     writedata = f@ref,
                      progressfunction=function(down,up)
                        cat("Downloading ", format(down[2], big.mark=",")," bytes\r"))
   }
-  
+
   close(f)
-  
+
   return(a)
 }
 
@@ -326,40 +326,40 @@ bdown <- function(url, file)
 
 gff2rds <- function(speciesName = c("HUMAN", "MOUSE", "RAT", "PIG"), forcedl)
 {
-  
-  
-  
+
+
+
   GFFEnding <- ".gff"
   wd <- "BasicData/"
-  GFFEndingGZ <- ".gff.gz"  
-  GFFPath <- "http://www.uniprot.org/uniprot/?format=gff&compress=yes&query=organism:"
-  
-  
+  GFFEndingGZ <- ".gff.gz"
+  GFFPath <- "https://www.uniprot.org/uniprot/?format=gff&compress=yes&query=organism:"
+
+
   #erstelle eine aktuelle Version der Datenbank
   #ACHTUNG: hier auch ueberpruefen ob Datei schon vorhanden
-  #save Uniprot Readme  
+  #save Uniprot Readme
   # Idee speichere die gffs passend zu den Aktualisierungen der Proteome
-  
+
   # check version/ release of Uniprot Data on uniprot and in BasicData folder
   cat("Check version \n")
   bdown("ftp://ftp.uniprot.org/pub/databases/uniprot/current_release/relnotes.txt",
         paste0(wd, "relnotes.txt"))
   version <- gsub(" ", "", readLines(paste0(wd, "relnotes.txt"), 1))
   cat("\n")
-  
+
   if (!dir.exists(paste0(wd, version)))
   {
-    dir.create(paste0(wd, version))      
+    dir.create(paste0(wd, version))
   }
-  
+
   if (!file.exists(paste0(wd, version, "/relnotes.txt")) | forcedl)
   {
     file.copy(paste0(wd, "relnotes.txt"), paste0(wd, version, "/relnotes.txt"), overwrite = FALSE)
   }
-  
+
   file.remove(paste0(wd, "relnotes.txt"))
-  result <- paste0(wd, version)  
-  
+  result <- paste0(wd, version)
+
   cat("Starting GFF file download, extraction and RDS creation...\n")
   for (s in speciesName){
     ##############################################
@@ -369,7 +369,7 @@ gff2rds <- function(speciesName = c("HUMAN", "MOUSE", "RAT", "PIG"), forcedl)
     GFFdest <- paste0(wd, version, "/", s, GFFEndingGZ)
     GFFfile <- paste0(wd, version, "/", s, GFFEnding)
     GFFrds <- paste0(wd, version, "/GFF", tolower(s), ".rds")
-    
+
     if(!file.exists(GFFfile) | forcedl )
     {
       cat("Downloading:", s, "\n")
@@ -378,14 +378,14 @@ gff2rds <- function(speciesName = c("HUMAN", "MOUSE", "RAT", "PIG"), forcedl)
       cat("- Finished downloading ", s, "\n")
       cat("Extracting:", s, "\n")
       gunzip(GFFdest, remove=TRUE, overwrite=TRUE)
-      
+
     }
     else
     {
       cat(GFFfile, " already exists. \n")
     }
-    
-    
+
+
     if(!file.exists(GFFrds) | forcedl )
     {
       cat("- Using GFF-file for species: ", s, "\n")
@@ -393,8 +393,8 @@ gff2rds <- function(speciesName = c("HUMAN", "MOUSE", "RAT", "PIG"), forcedl)
       gff <- gffRead(gfffile)
       #names(gff)
       #[1] "seqname"    "source"     "feature"    "start"      "end"        "score"      "strand"     "frame"      "attributes" NA
-      
-      
+
+
       cat("- Extracting attributes from GFF-file (this will take a while):\n")
       cat("   Notes...\n")
       gff$Note <- getAttributeField(gff$attributes, "Note")
@@ -404,23 +404,23 @@ gff2rds <- function(speciesName = c("HUMAN", "MOUSE", "RAT", "PIG"), forcedl)
       cat("- GFF-parsing finished", "\n")
       cat("- Saving GFF data table as RDS file for", s, "\n")
       #GFFrds <- paste0(wd, version, "/GFF", tolower(s), ".rds")
-      saveRDS(gff, file=GFFrds)  
+      saveRDS(gff, file=GFFrds)
       cat("- Finished GFF.RDS generation for ", s, "\n")
       cat("___________________________________________\n")
-      
+
     }
     else
     {
-      cat(GFFrds, " already exists. \n")      
+      cat(GFFrds, " already exists. \n")
     }
-    
-    
+
+
   }
   cat("- Finished GFF.RDS generation for ", "\n")
   cat(speciesName, "\n")
   cat("___________________________________________\n")
-  
-  
+
+
   return(result)
 }
 
@@ -431,10 +431,10 @@ gff2rds <- function(speciesName = c("HUMAN", "MOUSE", "RAT", "PIG"), forcedl)
 # Input: char vector pathdir
 #         char vector version
 #         char vector org
-#       
+#
 # Output: char vector result contains path to directory with gff-rds-files
 
-localgff2rds <- function(pathdir, version, org)  
+localgff2rds <- function(pathdir, version, org)
 {
   # check uniprot version/ release of Uniprot Data on uniprot and in BasicData folder
   cat("localgff2rds: Check version \n")
@@ -442,8 +442,8 @@ localgff2rds <- function(pathdir, version, org)
         paste0("BasicData/", "relnotes.txt"))
   actversion <- gsub(" ", "", readLines(paste0("BasicData/", "relnotes.txt"), 1))
   cat("\n")
-  
-  
+
+
   if (version == "actual")
   {
     # there is already a directory
@@ -451,23 +451,23 @@ localgff2rds <- function(pathdir, version, org)
     {
       file.copy(paste0("BasicData/", actversion,"/GFF",tolower(org),".rds"), paste0(pathdir,"/"))
       file.copy(paste0("BasicData/", actversion,"/",toupper(org),".gff"), paste0(pathdir,"/"))
-    
-      #there is no directory but there should be a newly made one from localfasta2rds         
+
+      #there is no directory but there should be a newly made one from localfasta2rds
     } else if (dir.exists(pathdir)){
-      
+
           # run download
           ##############################################
           ## Download GFF files and save as RDS files ##
           ##############################################
-          GFFEnding <- ".gff"  
-          GFFEndingGZ <- ".gff.gz"  
+          GFFEnding <- ".gff"
+          GFFEndingGZ <- ".gff.gz"
           GFFPath <- "http://www.uniprot.org/uniprot/?format=gff&compress=yes&query=organism:"
-          
+
           GFFsource <- paste0(GFFPath, toupper(org))
           GFFdest <- paste0(pathdir, "/", org, GFFEndingGZ)
           GFFfile <- paste0(pathdir, "/", toupper(org), GFFEnding)
           GFFrds <- paste0(pathdir, "/GFF", tolower(org), ".rds")
-          
+
           if(!file.exists(GFFfile) )
           {
             cat("localgff2rds: Downloading:", org, "\n")
@@ -476,14 +476,14 @@ localgff2rds <- function(pathdir, version, org)
             cat("localgff2rds: Finished downloading ", org, "\n")
             cat("localgff2rds: Extracting:", org, "\n")
             gunzip(GFFdest, remove = TRUE, overwrite = TRUE)
-            
+
           }
           else
           {
             cat("localgff2rds: ",GFFfile, " already exists. \n")
           }
-          
-          
+
+
           if(!file.exists(GFFrds))
           {
             cat("localgff2rds: Using GFF-file for species: ", org, "\n")
@@ -492,8 +492,8 @@ localgff2rds <- function(pathdir, version, org)
             gff <- gffRead(GFFfile)
             #names(gff)
             #[1] "seqname"    "source"     "feature"    "start"      "end"        "score"      "strand"     "frame"      "attributes" NA
-            
-            
+
+
             cat("- Extracting attributes from GFF-file (this will take a while):\n")
             cat("   Notes...\n")
             gff$Note <- getAttributeField(gff$attributes, "Note")
@@ -503,44 +503,44 @@ localgff2rds <- function(pathdir, version, org)
             cat("- GFF-parsing finished", "\n")
             cat("- Saving GFF data table as RDS file for", org, "\n")
             #GFFrds <- paste0(wd, version, "/GFF", tolower(s), ".rds")
-            saveRDS(gff, file=GFFrds)  
+            saveRDS(gff, file=GFFrds)
             cat("- Finished GFF.RDS generation for ", org, "\n")
             cat("___________________________________________\n")
-            
+
           }
           else
           {
-            cat(GFFrds, " already exists. \n")      
+            cat(GFFrds, " already exists. \n")
           }
-          
-          
+
+
     } else {
-      #none of the given directories exist 
+      #none of the given directories exist
       cat("localgff2rds ERROR: there is no pathdir with the given name\n")
       return("ERROR")
     }
-    
+
     # there is an archive file for this version
   } else if (dir.exists(paste0("BasicData/", version))){
-    
+
     file.copy(paste0("BasicData/", version,"/GFF",tolower(org),".rds"), paste0(pathdir,"/"))
     file.copy(paste0("BasicData/", version,"/",toupper(org),".gff"), paste0(pathdir,"/"))
-    
-    
+
+
   } else {
-    
+
     cat("localgff2rds ERROR: there is no archive with the given name\n")
     return("ERROR")
-    
-  }
-   
 
-  
-  cat("- Finished GFF.RDS generation for ", org, "\n")   
+  }
+
+
+
+  cat("- Finished GFF.RDS generation for ", org, "\n")
 
   result <- pathdir
   return(result)
-    
+
 }
 
 
@@ -548,14 +548,14 @@ localgff2rds <- function(pathdir, version, org)
 ############################################################
 # get values from a choosen attribute from gff
 
-getAttributeField <- function (x, field, attrsep = ";") 
+getAttributeField <- function (x, field, attrsep = ";")
 {
   s = strsplit(x, split = attrsep, fixed = TRUE)
-  sapply(s, function(atts) 
+  sapply(s, function(atts)
   {
     a = strsplit(atts, split = "=", fixed = TRUE)
     m = match(field, sapply(a, "[", 1))
-    if (!is.na(m)) 
+    if (!is.na(m))
     {
       rv = a[[m]][2]
     }
@@ -574,7 +574,7 @@ gffRead <- function(gffFile, nrows = -1)
   cat("Reading ", gffFile, ": ", sep="")
   gff = read.table(gffFile, sep="\t", as.is=TRUE, quote="",
                    header=FALSE, comment.char="#", nrows = nrows,
-                   colClasses=c("character", "character", "character", "integer",  
+                   colClasses=c("character", "character", "character", "integer",
                                 "integer",
                                 "character", "character", "character", "character"))
   # es entsteht eine leere Spalte am Ende der Tabelle, da im gff ein \t am Ende steht
@@ -583,13 +583,13 @@ gffRead <- function(gffFile, nrows = -1)
   if (sum(gff[, length(gff)] %in% "") == length(gff[, length(gff)]))
   {
     gff[, length(gff)] <- NULL
-  }  
-  
+  }
+
   colnames(gff) = c("seqname", "source", "feature", "start", "end",
                     "score", "strand", "frame", "attributes")
   cat("found", nrow(gff), "rows with classes:",
       paste(sapply(gff, class), collapse=", "), "\n")
   stopifnot(!any(is.na(gff$start)), !any(is.na(gff$end)))
-  
+
   return(gff)
-}
\ No newline at end of file
+}
